@@ -24,19 +24,28 @@ basePath="http://ci-files01-hki.ci.qt.io/input/android"
 
 toolsVersion="2.1"
 toolsFile="commandlinetools-linux-6609375_latest.zip"
-ndkVersionLatest="r25b"
+ndkVersionLatest="r26b"
 ndkVersionDefault=$ndkVersionLatest
 sdkBuildToolsVersion="34.0.0"
 sdkApiLevel="android-34"
 
 toolsSha1="9172381ff070ee2a416723c1989770cf4b0d1076"
-ndkSha1Latest="e27dcb9c8bcaa77b78ff68c3f23abcf6867959eb"
+ndkSha1Latest="fdf33d9f6c1b3f16e5459d53a82c7d2201edbcc4"
 ndkSha1Default=$ndkSha1Latest
-# Android automotive
-sdkApiLevelAutomotive="android-33"
-androidAutomotive13Url="$basePath/${sdkApiLevelAutomotive}_automotive.tar.gz"
-androidAutomotive="android-automotive"
-androidAutomotive13Sha="b020a938ec46af2510047284406e9bed608cad03"
+
+# Android 14 avd zip
+android14SystemZipName="android14system_UE1A_230829_036.tar.gz"
+android14SystemZipSha="ede80c6901e8fad1895c97a86542b8e072bb1ee5"
+android14SystemPath="$basePath/$android14SystemZipName"
+
+# Android Automotive max SDK level image
+sdkApiLevelAutomotiveMax="android-33"
+androidAutomotiveMaxUrl="$basePath/${sdkApiLevelAutomotiveMax}_automotive.tar.gz"
+androidAutomotiveMaxSha="b020a938ec46af2510047284406e9bed608cad03"
+# Android Automotive min SDK level image
+sdkApiLevelAutomotiveMin="android-29"
+androidAutomotiveMinUrl="$basePath/${sdkApiLevelAutomotiveMin}_automotive.tar.gz"
+androidAutomotiveMinSha="e6092585c00f87eb3b20a2eb7fdf6add42342d2f"
 
 toolsTargetFile="/tmp/$toolsFile"
 toolsSourceFile="$basePath/$toolsFile"
@@ -52,24 +61,26 @@ function InstallNdk() {
     ndkVersion=$1
     ndkSha1=$2
 
-    if [[ ! -d "$targetFolder/android-ndk-$ndkVersion" ]]; then
-
-        ndkFile="android-ndk-$ndkVersion-linux.zip"
-        ndkTargetFile="/tmp/$ndkFile"
-        ndkSourceFile="$basePath/$ndkFile"
-
-        DownloadURL "$ndkSourceFile" "$ndkSourceFile" "$ndkSha1" "$ndkTargetFile"
-        echo "Unzipping Android NDK to '$targetFolder'"
-        sudo unzip -q "$ndkTargetFile" -d "$targetFolder"
-        rm "$ndkTargetFile"
-    fi
+    ndkFile="android-ndk-$ndkVersion-linux.zip"
+    ndkTargetFile="/tmp/$ndkFile"
+    ndkSourceFile="$basePath/$ndkFile"
 
+    DownloadURL "$ndkSourceFile" "$ndkSourceFile" "$ndkSha1" "$ndkTargetFile"
+    echo "Unzipping Android NDK to '$targetFolder'"
+    # Get the package base directory name as string
+    zipBase=$(sudo zipinfo -1 "$ndkTargetFile" 2>/dev/null | awk '!seen {sub("/.*",""); print; seen=1}')
+    sudo unzip -q "$ndkTargetFile" -d "$targetFolder"
+    rm "$ndkTargetFile"
+    androidNdkRoot="${targetFolder}/${zipBase}"
 }
 
 InstallNdk $ndkVersionDefault $ndkSha1Default
-SetEnvVar "ANDROID_NDK_ROOT_DEFAULT" "$targetFolder/android-ndk-$ndkVersionDefault"
-InstallNdk $ndkVersionLatest $ndkSha1Latest
-SetEnvVar "ANDROID_NDK_ROOT_LATEST" "$targetFolder/android-ndk-$ndkVersionLatest"
+SetEnvVar "ANDROID_NDK_ROOT_DEFAULT" "$androidNdkRoot"
+
+if [ "$ndkVersionDefault" != "$ndkVersionLatest" ]; then
+    InstallNdk $ndkVersionLatest $ndkSha1Latest
+fi
+SetEnvVar "ANDROID_NDK_ROOT_LATEST" "$androidNdkRoot"
 
 echo "Changing ownership of Android files."
 if uname -a |grep -q "el7"; then
@@ -120,12 +131,27 @@ EOB
 cd "$sdkTargetFolder/cmdline-tools/tools/bin"
 ./sdkmanager --install "emulator" --sdk_root="$sdkTargetFolder" \
     | eval "$sdkmanager_no_progress_bar_cmd"
+
+echo "Download and unzip Android Emulator version 32.1.15"
+emulatorFileName="emulator-linux_x64-10696886.zip"
+emulatorCiUrl="https://ci-files01-hki.ci.qt.io/input/android/$emulatorFileName"
+emulatorUrl="http://dl.google.com/android/repository/$emulatorFileName"
+emulatorTargetFile="$sdkTargetFolder/$emulatorFileName"
+emulatorSha1="b78f4d2c22d6aa5ca83d26ccb68cbf885a273888"
+DownloadURL "$emulatorCiUrl" "$emulatorUrl" "$emulatorSha1" "$emulatorTargetFile"
+echo "Unzipping the Android Emulator to '$sdkTargetFolder'"
+sudo unzip -o -q "$emulatorTargetFile" -d "$sdkTargetFolder"
+rm "$emulatorTargetFile"
+
 echo "y" | ./sdkmanager --install "system-images;android-23;google_apis;x86" \
     | eval "$sdkmanager_no_progress_bar_cmd"
 echo "y" | ./sdkmanager --install "system-images;android-33;google_apis;x86_64" \
     | eval "$sdkmanager_no_progress_bar_cmd"
-echo "y" | ./sdkmanager --install "system-images;android-34;google_apis;x86_64" \
-    | eval "$sdkmanager_no_progress_bar_cmd"
+
+echo "Extract stored Android 14 Beta $android14SystemZipName"
+DownloadURL "$android14SystemPath" "$android14SystemPath" "$android14SystemZipSha" \
+    "/tmp/$android14SystemZipName"
+sudo tar -xzf "/tmp/$android14SystemZipName" -C "$sdkTargetFolder/system-images"
 
 echo "Checking the contents of Android SDK again..."
 ls -l "$sdkTargetFolder"
@@ -139,12 +165,19 @@ echo "no" | ./avdmanager create avd -n emulator_x86_64_api_33 -c 2048M -f \
 echo "no" | ./avdmanager create avd -n emulator_x86_64_api_34 -c 2048M -f \
     -k "system-images;android-34;google_apis;x86_64"
 
-echo "Install $sdkApiLevelAutomotive $androidAutomotive"
-DownloadURL "$androidAutomotive13Url" "$androidAutomotive13Url" "$androidAutomotive13Sha" \
-    "/tmp/${sdkApiLevelAutomotive}_automotive.tar.gz"
-sudo tar -xzf "/tmp/${sdkApiLevelAutomotive}_automotive.tar.gz" -C "$sdkTargetFolder/system-images"
+echo "Install maximum supported SDK level image for Android Automotive $sdkApiLevelAutomotiveMax"
+DownloadURL "$androidAutomotiveMaxUrl" "$androidAutomotiveMaxUrl" "$androidAutomotiveMaxSha" \
+    "/tmp/${sdkApiLevelAutomotiveMax}_automotive.tar.gz"
+sudo tar -xzf "/tmp/${sdkApiLevelAutomotiveMax}_automotive.tar.gz" -C "$sdkTargetFolder/system-images"
 echo "no" | ./avdmanager create avd -n automotive_emulator_x86_64_api_33 -c 2048M -f \
-    -k "system-images;${sdkApiLevelAutomotive};${androidAutomotive};x86_64"
+    -k "system-images;${sdkApiLevelAutomotiveMax};android-automotive;x86_64"
+
+echo "Install minimum supported SDK level image for Android Automotive $sdkApiLevelAutomotiveMin"
+DownloadURL "$androidAutomotiveMinUrl" "$androidAutomotiveMinUrl" "$androidAutomotiveMinSha" \
+    "/tmp/${sdkApiLevelAutomotiveMin}_automotive.tar.gz"
+sudo tar -xzf "/tmp/${sdkApiLevelAutomotiveMin}_automotive.tar.gz" -C $sdkTargetFolder/system-images
+echo "no" | ./avdmanager create avd -n automotive_emulator_x86_64_api_29 -c 2048M -f \
+    -k "system-images;${sdkApiLevelAutomotiveMin};android-automotive;x86_64"
 
 # Purely informative, show the list of avd devices
 ./avdmanager list avd
